trove library

Classes

Dice
A multi-sided die that produces a random number between 1 and sides.
PlayingCard
A standard playing card with a rank and suit.

Enums

PlayingCardRank
Ranks for a standard playing card.
PlayingCardSuit
Suits for a standard playing card.

Constants

d10 → const Dice
A dice with 10-sides.
d100 → const Dice
A dice with 100-sides.
d12 → const Dice
A dice with 12-sides.
d20 → const Dice
A dice with 20-sides.
d4 → const Dice
A dice with 4-sides.
d6 → const Dice
A dice with 6-sides.
d8 → const Dice
A dice with 8-sides.